@@ -125,12 +125,12 @@
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Global Screen Scaling</source>
-        <translation type="unfinished"></translation>
+        <translation>Escala global de la pantalla</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="123"/>
         <source>Scale factor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Factor d&apos;escala:</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="149"/>
