@@ -11,7 +11,7 @@
     <message>
         <location filename="../autostartedit.ui" line="20"/>
         <source>Name:</source>
-        <translation>Nom :</translation>
+        <translation>Nom&#x202f;:</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="27"/>
@@ -21,7 +21,7 @@
     <message>
         <location filename="../autostartedit.ui" line="47"/>
         <source>Command:</source>
-        <translation>Comanda :</translation>
+        <translation>Comanda&#x202f;:</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="57"/>
@@ -49,12 +49,12 @@
     <message>
         <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
-        <translation>Emplaçament : %1</translation>
+        <translation>Emplaçament&#x202f;: %1</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
-        <translation>Remplaçament : %1</translation>
+        <translation>Remplaçament&#x202f;: %1</translation>
     </message>
 </context>
 <context>
@@ -87,7 +87,7 @@
     <message>
         <location filename="../autostartpage.cpp" line="142"/>
         <source>File &apos;%1&apos; already exists!</source>
-        <translation>Lo fichièr « %1 » existís ja !</translation>
+        <translation>Lo fichièr «&#x202f;%1&#x202f;» existís ja&#x202f;!</translation>
     </message>
 </context>
 <context>
@@ -130,7 +130,7 @@
     <message>
         <location filename="../basicsettings.ui" line="123"/>
         <source>Scale factor:</source>
-        <translation>Factor d’escala :</translation>
+        <translation>Factor d’escala&#x202f;:</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="149"/>
@@ -150,7 +150,7 @@
     <message>
         <location filename="../basicsettings.ui" line="169"/>
         <source>Suspend/hibernate after lock delay:</source>
-        <translation>Suspendre/Ivernar aprèp lo relambi de verrolhatge :</translation>
+        <translation>Suspendre/Ivernar aprèp lo relambi de verrolhatge&#x202f;:</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="182"/>
