@@ -80,12 +80,12 @@
         <translation>Použiť automatické spustenie</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="143"/>
+        <location filename="../autostartpage.cpp" line="142"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="143"/>
+        <location filename="../autostartpage.cpp" line="142"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>Súbor &apos;%1&apos; už existuje!</translation>
     </message>
@@ -119,26 +119,36 @@
     </message>
     <message>
         <location filename="../basicsettings.ui" line="111"/>
-        <source>Leave Session</source>
-        <translation>Opustiť sedenie</translation>
+        <source>Global Screen Scaling</source>
+        <translation>Globálne meradlo zobrazenia</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="117"/>
+        <location filename="../basicsettings.ui" line="123"/>
+        <source>Scale factor:</source>
+        <translation>Násobok meradla:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="149"/>
+        <source>Leave Session</source>
+        <translation>Opustiť reláciu</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="155"/>
         <source>Ask for confirmation to leave session</source>
         <translation>Požiadať o potvrdenie pre opustenie relácie</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="124"/>
+        <location filename="../basicsettings.ui" line="162"/>
         <source>Lock screen before suspending/hibernating</source>
         <translation>Uzamknúť monitor pred prepnutím do pohotovostného stavu / hibernácie</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="131"/>
+        <location filename="../basicsettings.ui" line="169"/>
         <source>Suspend/hibernate after lock delay:</source>
         <translation>Prepnutie do pohotovostného stavu / hibernácie po uplynutí:</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="144"/>
+        <location filename="../basicsettings.ui" line="182"/>
         <source> ms</source>
         <translation> ms</translation>
     </message>
@@ -148,7 +158,7 @@
         <translation>Základné nastavenia</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="156"/>
+        <location filename="../basicsettings.cpp" line="176"/>
         <source>Select a window manager</source>
         <translation>Vybrať správcu okien</translation>
     </message>
@@ -158,7 +168,7 @@
     <message>
         <location filename="../environmentpage.ui" line="17"/>
         <source>Add</source>
-        <translation>Pridaj</translation>
+        <translation>Pridať</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="24"/>
@@ -173,7 +183,7 @@
     <message>
         <location filename="../environmentpage.ui" line="61"/>
         <source>Variable Name</source>
-        <translation>Premenné meno</translation>
+        <translation>Názov premennej</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="66"/>
@@ -217,12 +227,12 @@
         <translation>Prostredie (Rozšírené)</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="87"/>
+        <location filename="../sessionconfigwindow.cpp" line="91"/>
         <source>Session Restart Required</source>
         <translation>Vyžaduje sa reštart relácie</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="88"/>
+        <location filename="../sessionconfigwindow.cpp" line="92"/>
         <source>Some settings will not take effect until the next log in.</source>
         <translation>Niektoré nastavenia sa prejavia až po ďalšom prihlásení.</translation>
     </message>
@@ -235,17 +245,17 @@
         <translation>Miesto pre osobné súbory</translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="185"/>
+        <location filename="../userlocationspage.cpp" line="184"/>
         <source>LXQt Session Settings - User Directories</source>
         <translation>Nastavenie relácie LXQt - Užívateľské adresáre</translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="186"/>
+        <location filename="../userlocationspage.cpp" line="185"/>
         <source>An error ocurred while applying the settings for the %1 location</source>
         <translation>Pri aplikovaní nastavení sa vyskytla chyba %1</translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="202"/>
+        <location filename="../userlocationspage.cpp" line="201"/>
         <source>Choose Location</source>
         <translation>Vybrať umiestnenie</translation>
     </message>
